@@ -7,6 +7,12 @@ use warnings;
 
 use HTML::Parser;
 
+our $VERSION;
+
+BEGIN {
+    $VERSION = '0.0.2';
+}
+
 my $parser = HTML::Parser->new(api_version => 3);
 
 sub handler {
@@ -31,4 +37,13 @@ sub run {
     $parser->eof;
 }
 
-;
+1;
+
+=head1 NAME
+
+ExtractLinks
+
+=head1 DESCRIPTION
+
+Extract hrefs from HTML documents to stdout.
+
